@@ -1,5 +1,5 @@
-%% Copyright (C) 2015 Colin B. Macdonald
-%% Copyright (C) 2016 Colin B. Macdonald, Alex Vong
+%% Copyright (C) 2015-2016 Colin B. Macdonald
+%% Copyright (C) 2016 Alex Vong
 %%
 %% This file is part of OctSymPy.
 %%
@@ -50,11 +50,16 @@
 %% @end group
 %% @end example
 %%
-%% @seealso{cross}
+%% @seealso{@@sym/cross}
 %% @end defmethod
 
+
 function c = dot(a, b)
 
+  if (nargin ~= 2)
+    print_usage ();
+  end
+
   % conjugate linear in the 1st slot to match the behavior of @double/dot
   cmd = { 'a, b = _ins'
           'return a.conjugate().dot(b),'
@@ -65,6 +70,8 @@ function c = dot(a, b)
 end
 
 
+%!error <Invalid> dot (sym(1), 2, 3)
+
 %!test
 %! a = sym([1; 1; 0]);
 %! b = sym([1; 2; 4]);
