@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2014-2017 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -42,8 +42,6 @@
 %% @seealso{@@sym/vertcat, @@sym/cat}
 %% @end defop
 
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
 
 function h = horzcat(varargin)
 
@@ -59,10 +57,12 @@ function h = horzcat(varargin)
           '            pass'
           '        else:'
           '            _proc.append(i)'
-          'return sp.Matrix.hstack(*_proc),'
+          'return sp.MatrixBase.hstack(*_proc),'
           };
 
-  varargin = sym(varargin);
+  for i = 1:nargin
+    varargin{i} = sym(varargin{i});
+  end
   h = python_cmd (cmd, varargin{:});
 
 end
@@ -132,3 +132,9 @@ end
 %! v = [sym(1) sym(2)];
 %! q = sym(ones(3, 0));
 %! w = horzcat(v, q);
+
+%!test
+%! % issue #700
+%! A = sym ([1 2]);
+%! B = simplify (A);
+%! assert (isequal ([B A], [A B]))
