@@ -42,14 +42,14 @@
 %%       ⎢    ⎥
 %%       ⎣0  x⎦
 %% A^2
-%%   @result{} ans = (sym 2×2 matrix)
+%%   @result{} (sym 2×2 matrix)
 %%       ⎡ 2           ⎤
 %%       ⎢π   2⋅x + 2⋅π⎥
 %%       ⎢             ⎥
 %%       ⎢        2    ⎥
 %%       ⎣0      x     ⎦
 %% A^2 == A*A
-%%   @result{} ans = (sym 2×2 matrix)
+%%   @result{} (sym 2×2 matrix)
 %%       ⎡True  True⎤
 %%       ⎢          ⎥
 %%       ⎣True  True⎦
@@ -59,8 +59,6 @@
 %% @seealso{@@sym/power}
 %% @end defop
 
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
 
 function z = mpower(x, y)
 
@@ -73,19 +71,13 @@ function z = mpower(x, y)
   end
 
   cmd = { 'x, y = _ins'
-          'if x.is_Matrix and not y.is_Matrix and Version(spver) < Version("0.7.7.dev"):'
-          '    return sympy.MatPow(x, y).doit()'
-          'else:'
-          '    return x**y'
-        };
+          'return x**y' };
 
   z = python_cmd (cmd, sym(x), sym(y));
 
-  % FIXME: with some future SymPy (>0.7.6.1?), we may be able to use:
-  %z = python_cmd ('return _ins[0]**_ins[1],', sym(x), sym(y))
-
 end
 
+
 %!test
 %! syms x
 %! assert(isequal(x^(sym(4)/5), x.^(sym(4)/5)))
@@ -113,14 +105,10 @@ end
 
 %!test
 %! % non-integer power
-%! if (python_cmd ('return Version(spver) < Version("0.7.7.dev"),'))
-%!   fprintf('\n  skipping known failure b/c SymPy <= 0.7.6.x\n')
-%! else
 %! A = sym([1 2; 0 3]);
 %! B = A^pi;
 %! C = [1 -1+3^sym(pi); 0 sym(3)^pi];
 %! assert (isequal (B, C))
-%! end
 
 %!test
 %! % matpow
@@ -142,11 +130,18 @@ end
 %! C = subs(B, n, 0);
 %! assert (isequal (C, sym(eye(2))))
 
-%!error <NotImplementedError>
-%! % scalar^array not implemented
+%!test
+%! % scalar^array works in SymPy > 1.0.0, otherwise not implemented
 %! syms x
 %! A = [1 2; 3 4];
-%! B = x^A;
+%! try
+%!   B = x^A;
+%!   waserr = false;
+%! catch
+%!   waserr = true;
+%!   notimpl = any (strfind (lasterr (), 'NotImplementedError'));
+%! end
+%! assert ((~ waserr && strcmp (regexprep (disp (B, 'flat'), '\s+', ''), 'x**Matrix([[1,2],[3,4]])')) || (waserr && notimpl))
 
 %!error
 %! A = sym([1 2; 3 4]);
