@@ -1,4 +1,6 @@
-%% Copyright (C) 2014, 2015 Colin B. Macdonald
+%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2016 Lagu
+%% Copyright (C) 2016 Abhinav Tripathi
 %%
 %% This file is part of OctSymPy.
 %%
@@ -17,19 +19,64 @@
 %% If not, see <http://www.gnu.org/licenses/>.
 
 %% -*- texinfo -*-
-%% @deftypefn  {Function File} {@var{z} =} mat_replace (@var{A}, @var{subs}, @var{rhs})
+%% @defun mat_replace (@var{A}, @var{subs}, @var{rhs})
 %% Private helper routine for setting symbolic array entries.
 %%
-%% @end deftypefn
+%% @end defun
 
 %% Author: Colin B. Macdonald
 %% Keywords: symbolic
 
 function z = mat_replace(A, subs, b)
 
-  if ( (length(subs) == 1) && (islogical(subs{1})) )
+  if (length (subs) == 1 && islogical (subs{1}))
     %% A(logical) = B
-    z = mat_mask_asgn(A, subs{1}, b);
+    subs{1} = find (subs{1});
+    if isempty (subs{1})
+      z = A;
+      return;
+    end
+  end
+  %% Check when b is []
+  if (isempty(b))
+    switch length(subs)
+      case 1
+        if strcmp(subs{1}, ':')
+          z = sym([]);
+          return
+        else
+          if rows(A) == 1
+            z = python_cmd('_ins[0].col_del(_ins[1] - 1); return _ins[0],', A, sym(subs{1}));
+            return
+          elseif columns(A) == 1
+            z = python_cmd('_ins[0].row_del(_ins[1] - 1); return _ins[0],', A, sym(subs{1}));
+            return
+          else
+            z = sym([]);
+            for i=1:A.size(2)
+              z = [z subsref(A, substruct ('()', {':', i})).'];
+            end
+            z = subsasgn (z, substruct ('()', {subs{1}}), []);
+            return
+          end
+        end
+      case 2
+        if strcmp(subs{1}, ':')
+          z = python_cmd('_ins[0].col_del(_ins[1] - 1); return _ins[0],', A, sym(subs{2}));
+          return
+        elseif strcmp(subs{2}, ':')
+          z = python_cmd('_ins[0].row_del(_ins[1] - 1); return _ins[0],', A, sym(subs{1}));
+          return
+        else
+          error('A null assignment can only have one non-colon index.'); % Standard octave error
+        end
+      otherwise
+        error('Unexpected subs input')
+    end
+  end
+
+  if (length(subs) == 1 && strcmp(subs{1}, ':') && length(b) == 1)
+    z = python_cmd('return ones(_ins[0], _ins[1])*_ins[2],', A.size(1), A.size(2), sym(b));
     return
 
   elseif (length(subs) == 1)
@@ -43,6 +90,9 @@ function z = mat_replace(A, subs, b)
     else
       % linear indices into 2D array
       [r, c] = ind2sub (size(A), subs{1});
+      % keep all the indices in a row vector
+      r = reshape (r, 1, []);
+      c = reshape (c, 1, []);
     end
 
   elseif (length(subs) == 2)
