@@ -1,4 +1,5 @@
-%% Copyright (C) 2014 Colin B. Macdonald
+%% Copyright (C) 2014, 2016 Colin B. Macdonald
+%% Copyright (C) 2016 Lagu
 %%
 %% This file is part of OctSymPy.
 %%
@@ -17,31 +18,55 @@
 %% If not, see <http://www.gnu.org/licenses/>.
 
 %% -*- texinfo -*-
-%% @deftypefn  {Function File} {@var{x} =} real (@var{z})
+%% @documentencoding UTF-8
+%% @defmethod @@sym real (@var{z})
 %% Real part of a symbolic expression.
 %%
-%% @seealso{imag, conj, ctranspose}
+%% Examples:
+%% @example
+%% @group
+%% syms z
+%% real(z)
+%%   @result{} ans = (sym) re(z)
+%% @end group
 %%
-%% @end deftypefn
+%% @group
+%% syms x real
+%% real(x)
+%%   @result{} ans = (sym) x
+%%
+%% real([x  sym(pi) + 6i  7  3i])
+%%   @result{} ans = (sym) [x  π  7  0]  (1×4 matrix)
+%% @end group
+%% @end example
+%%
+%% @seealso{@@sym/imag, @@sym/conj, @@sym/ctranspose}
+%% @end defmethod
 
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
 
-function x = real(z)
+function y = real(z)
+  if (nargin ~= 1)
+    print_usage ();
+  end
 
-  x = (z + conj(z))/2;
+  y = elementwise_op ('re', z);
 
 end
 
 
-%!assert(isequal(real(sym(4)+3i),4))
+%!assert (isequal (real (sym (4) + 3i),4))
 
 %!test
 %! syms x y real
 %! z = x + 1i*y;
-%! assert(isequal(real(z),x))
+%! assert (isequal (real (z),x))
 
 %!test
 %! syms x y real
-%! Z = [4  x + 1i*y; x 4+3i];
-%! assert(isequal(real(Z),[4 x; x 4]))
+%! Z = [4  x + 1i*y; x 4 + 3i];
+%! assert (isequal (real (Z),[4 x; x 4]))
+
+%!test
+%! syms x real
+%! d = exp (x*i);
+%! assert (isequal (real (d), cos (x)))
