@@ -85,15 +85,6 @@
 %%   @result{} g(x, y) = (symfun) g(x, y)
 %% @end group
 %% @end example
-%% However, on old versions of Octave (before 4.0), one needed to
-%% workaround a parsing bug:
-%% @example
-%% @group
-%% syms 'g(x, y)'
-%% g
-%%   @result{} g(x, y) = (symfun) g(x, y)
-%% @end group
-%% @end example
 %%
 %% As the above examples demonstrate, it is usually not necessary to
 %% call symfun directly.  However, it can be done:
@@ -130,6 +121,21 @@
 %% @end group
 %% @end example
 %%
+%% It is possible to compose one symfun inside another.  For example, to
+%% demonstrate the chain rule, we might do:
+%% @example
+%% @group
+%% syms f(t) g(t)
+%% F(t) = f(g(t))
+%%   @result{} F(t) = (symfun) f(g(t))
+%% diff(F, t)
+%%   @result{} ans(t) = (symfun)
+%%       d        ⎛ d        ⎞│
+%%       ──(g(t))⋅⎜───(f(ξ₁))⎟│
+%%       dt       ⎝dξ₁       ⎠│ξ₁=g(t)
+%% @end group
+%% @end example
+%%
 %% @seealso{sym, syms}
 %% @end deftypemethod
 
@@ -144,6 +150,8 @@ function f = symfun(expr, vars)
     vars = sym('x');
   elseif (nargin == 1)
     print_usage ();
+  elseif (nargin > 2)
+    print_usage ();
   end
 
   % if the vars are in a sym array, put them in a cell array
@@ -158,22 +166,15 @@ function f = symfun(expr, vars)
   % check that vars are unique Symbols
   cmd = { 'L, = _ins'
           'if not all([x is not None and x.is_Symbol for x in L]):'
-	  '    return False'
-	  'return len(set(L)) == len(L)' };
+          '    return False'
+          'return len(set(L)) == len(L)' };
   if (~ python_cmd (cmd, vars))
     error('OctSymPy:symfun:argNotUniqSymbols', ...
           'symfun arguments must be unique symbols')
   end
 
   if (ischar (expr))
-    % FIXME: drop this later
-    warning('symfun: deprecated: symfun(''f'', x) format not supported')
-    tok = mystrsplit(expr, {'(', ')', ','});
-    fname = strtrim(tok{1});
-    assert (isvarname (fname))
-    cmd = {['_f = sp.Function("' fname '")(*_ins)'] ...
-            'return (_f,)' };
-    expr = python_cmd (cmd, vars{:});
+    error ('symfun(<string>, x) is not supported, see "help symfun" for options')
   end
 
   if (isa(expr, 'symfun'))
@@ -196,6 +197,10 @@ function f = symfun(expr, vars)
 end
 
 
+%!error <Invalid> symfun (1, sym('x'), 3)
+
+%!error <not supported> symfun ('f', sym('x'))
+
 %!test
 %! syms x y
 %! syms f(x)
@@ -257,7 +262,7 @@ end
 %! f(5);
 %! assert (length (argnames (f)) == 1)
 %! assert (isequal (argnames (f), t))
-%! assert (isequal( diff(f,x), sym(0)))
+%! assert (isequal( formula(diff(f,x)), sym(0)))
 
 %!test
 %! % replace g with shorter and specific fcn
@@ -276,26 +281,35 @@ end
 
 %!test
 %! % Bug #41: Octave <= 3.8 parser fails without quotes around 2D fcn
-%! % (put inside eval to hide from 3.6 parser)
-%! if exist('OCTAVE_VERSION', 'builtin')
-%!   if (compare_versions (OCTAVE_VERSION (), '4.0.0', '>='))
-%!     syms x y
-%!     eval('syms g(x,y)')
-%!     assert (isa (g, 'symfun'))
-%!   end
-%! else  % matlab
-%!   syms x y
-%!   eval('syms g(x,y)')
-%!   assert (isa (g, 'symfun'))
-%! end
+%! syms x y
+%! eval('syms g(x,y)')
+%! assert (isa (g, 'symfun'))
+
+%!test
+%! % and these days it works without eval trick
+%! syms g(x,y)
+%! assert (isa (g, 'symfun'))
 
 %!test
 %! % syms f(x) without defining x
-%! clear
+%! clear x
 %! syms f(x)
 %! assert(isa(f, 'symfun'))
 %! assert(isa(x, 'sym'))
 
+%!test
+%! % SMT compat: symfun indep var overwrites existing var
+%! t = 6;
+%! syms f(t)
+%! assert (logical (t ~= 6))
+
+%!test
+%! % SMT compat: symfun indep var overwrites existing var, even if sym
+%! syms x
+%! t = x;
+%! syms f(t)
+%! assert (~ logical (t == x))
+
 %!test
 %! syms x y
 %! f(x) = x^2;
@@ -308,16 +322,16 @@ end
 
 %!test
 %! % syms has its own parsing code, check it works
-%! syms 'f(x,y)'
+%! syms f(x,y)
 %! g = f;
-%! syms 'f(x, y)'
+%! syms f(x, y)
 %! assert (isequal (f, g))
 %! syms 'f( x,  y  )'
 %! assert (isequal (f, g))
 
 %!test
 %! % syms own parsing code should not reorder the vars
-%! syms 'f(y, x)'
+%! syms f(y, x)
 %! v = f.vars;
 %! assert (isequal (v{1}, y) && isequal (v{2}, x))
 
