@@ -1,4 +1,4 @@
-%% Copyright (C) 2014, 2015 Colin B. Macdonald
+%% Copyright (C) 2014-2016 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -18,8 +18,8 @@
 
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
-%% @deftypefn {Function File} {@var{vars} =} symvar (@var{f})
-%% @deftypefnx {Function File} {@var{vars} =} symvar (@var{f}, @var{n})
+%% @defmethod  @@symfun symvar (@var{f})
+%% @defmethodx @@symfun symvar (@var{f}, @var{n})
 %% Find symbols in symfun and return them as a symbolic vector.
 %%
 %% If @var{n} specified, we take from the explicit function variables
@@ -29,26 +29,26 @@
 %% Example:
 %% @example
 %% @group
-%% >> syms a x f(t, s)
-%% >> symvar (f, 1)
-%%    @result{} (sym) t
-%% >> symvar (f, 2)
-%%    @result{} (sym) [t  s]  (1×2 matrix)
+%% syms a x f(t, s)
+%% symvar (f, 1)
+%%   @result{} (sym) t
+%% symvar (f, 2)
+%%   @result{} (sym) [t  s]  (1×2 matrix)
 %% @end group
 %% @end example
 %% Note preference for the arguments of the symfun:
 %% @example
 %% @group
-%% >> h = f*a + x
-%%    @result{} h(t, s) = (symfun) a⋅f(t, s) + x
-%% >> symvar (h, 1)
-%%    @result{} (sym) t
-%% >> symvar (h, 2)
-%%    @result{} (sym) [t  s]  (1×2 matrix)
-%% >> symvar (h, 3)
-%%    @result{} (sym) [t  s  x]  (1×3 matrix)
-%% >> symvar (h, 4)
-%%    @result{} (sym) [t  s  x  a]  (1×4 matrix)
+%% h = f*a + x
+%%   @result{} h(t, s) = (symfun) a⋅f(t, s) + x
+%% symvar (h, 1)
+%%   @result{} (sym) t
+%% symvar (h, 2)
+%%   @result{} (sym) [t  s]  (1×2 matrix)
+%% symvar (h, 3)
+%%   @result{} (sym) [t  s  x]  (1×3 matrix)
+%% symvar (h, 4)
+%%   @result{} (sym) [t  s  x  a]  (1×4 matrix)
 %% @end group
 %% @end example
 %%
@@ -57,12 +57,12 @@
 %% For example:
 %% @example
 %% @group
-%% >> symvar (f, 2)
-%%    @result{} (sym) [t  s]  (1×2 matrix)
-%% >> symvar (f)
-%%    @result{} (sym) [s  t]  (1×2 matrix)
-%% >> symvar (h)
-%%    @result{} (sym) [a  s  t  x]  (1×4 matrix)
+%% symvar (f, 2)
+%%   @result{} (sym) [t  s]  (1×2 matrix)
+%% symvar (f)
+%%   @result{} (sym) [s  t]  (1×2 matrix)
+%% symvar (h)
+%%   @result{} (sym) [a  s  t  x]  (1×4 matrix)
 %% @end group
 %% @end example
 %%
@@ -71,21 +71,21 @@
 %% (tested with version 2014a).  For example:
 %% @example
 %% @group
-%% >> syms x y s t
-%% >> f(t, s) = 1
-%%    @result{} f(t, s) = (symfun) 1
-%% >> symvar (f, 1)
-%%    @result{} (sym) t
-%% >> symvar (f, 2)
-%%    @result{} (sym) [t  s]  (1×2 matrix)
+%% syms x y s t
+%% f(t, s) = 1
+%%   @result{} f(t, s) = (symfun) 1
+%% symvar (f, 1)
+%%   @result{} (sym) t
+%% symvar (f, 2)
+%%   @result{} (sym) [t  s]  (1×2 matrix)
 %% @end group
 %% @end example
 %% However, when the symfun formula does not depend on the
 %% arguments, the results are not the same:
 %% @example
 %% @group
-%% >> symvar (f)  % SMT would give []
-%%    @result{} (sym) [s  t]  (1×2 matrix)
+%% symvar (f)  % SMT would give []
+%%   @result{} (sym) [s  t]  (1×2 matrix)
 %% @end group
 %% @end example
 %%
@@ -93,11 +93,8 @@
 %% they will both appear in the output.  It is not well-defined
 %% in what order they appear.
 %%
-%% @seealso{findsym, findsymbols, argnames, formula}
-%% @end deftypefn
-
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
+%% @seealso{findsymbols, @@symfun/argnames, @@symfun/formula}
+%% @end defmethod
 
 function vars = symvar(F, Nout)
 
@@ -132,7 +129,7 @@ function a = remove_dupes(symvars, vars)
   keep = logical(ones(1, length(symvars)));
   for j = 1:length(symvars)
     for i = 1:M
-      if (strcmp(char(symvars(j)), char(vars(i))))
+      if (strcmp (sympy (symvars(j)), sympy (vars(i))))
         keep(j) = false;
         break
       end
@@ -143,8 +140,8 @@ end
 
 
 %!test
-%! % basic, quotes are oct 3.6 workaround
-%! syms 'f(t, s)'
+%! % basic
+%! syms f(t, s)
 %! assert (isequal (symvar (f, 0), sym([])))
 %! assert (isequal (symvar (f, 1), t))
 %! assert (isequal (symvar (f, 2), [t s]))
@@ -166,7 +163,7 @@ end
 
 %!test
 %! % preference for the explicit variables
-%! syms a x 'f(t, s)'
+%! syms a x f(t, s)
 %! h = f*a + x;
 %! assert (isequal (symvar (h, 1), t))
 %! assert (isequal (symvar (h, 2), [t s]))
