@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2016 Colin B. Macdonald
+# Copyright (C) 2014-2017 Colin B. Macdonald
 # Free Software without warranty, GPL-3.0+: see python_header.m
 
 # In some cases this code is fed into stdin: two blank lines between
@@ -37,6 +37,9 @@ try:
     from sympy.matrices.expressions.matexpr import MatrixElement
     # for hypergeometric
     from sympy.functions.special.hyper import TupleArg
+    # for sets
+    from sympy.sets.fancysets import *
+    from sympy.sets.sets import *
     from sympy.utilities.iterables import uniq
     import copy
     import binascii
@@ -44,6 +47,9 @@ try:
     import codecs
     import xml.etree.ElementTree as ET
     from distutils.version import LooseVersion
+    import itertools
+    import collections
+    from re import split
 except:
     echo_exception_stdout("in python_header import block")
     raise
@@ -85,78 +91,6 @@ except:
     raise
 
 
-# FIXME: Remove all this when we deprecate 0.7.6.x support.
-if Version(spver) >= Version("0.7.7.dev"):
-    my_srepr = sympy.srepr
-else:
-    def _monkey_patch_matpow_doit(self, **kwargs):
-        deep = kwargs.get('deep', True)
-        if deep:
-            args = [arg.doit(**kwargs) for arg in self.args]
-        else:
-            args = self.args
-        base = args[0]
-        exp = args[1]
-        if isinstance(base, MatrixBase) and exp.is_number:
-            if exp is S.One:
-                return base
-            return base**exp
-        if exp.is_zero and base.is_square:
-            return Identity(base.shape[0])
-        elif exp is S.One:
-            return base
-        return MatPow(base, exp)
-    sympy.MatPow.doit = _monkey_patch_matpow_doit
-    sympy.MatAdd.doit_orig = sympy.MatAdd.doit
-    def _monkey_patch_matadd_doit(self, **kwargs):
-        deep = kwargs.get('deep', True)
-        if deep:
-            args = [arg.doit(**kwargs) for arg in self.args]
-        else:
-            args = self.args
-        return MatAdd(*args).doit_orig(**kwargs)
-    sympy.MatAdd.doit = _monkey_patch_matadd_doit
-    try:
-        class _ReprPrinter_w_asm(sympy.printing.repr.ReprPrinter):
-            def _print_Symbol(self, expr):
-                asm = expr.assumptions0
-                # SymPy < 0.7.7: srepr does not list assumptions.
-                # Abbreviate some common cases.
-                asm_default = {"commutative":True}
-                asm_real = {"commutative":True, "complex":True, "hermitian":True,
-                            "imaginary":False, "real":True}
-                asm_pos = {"commutative":True, "complex":True, "hermitian":True,
-                           "imaginary":False, "negative":False, "nonnegative":True,
-                           "nonpositive":False, "nonzero":True, "positive":True,
-                           "real":True, "zero":False}
-                asm_neg = {"commutative":True, "complex":True, "hermitian":True,
-                           "imaginary":False, "negative":True, "nonnegative":False,
-                           "nonpositive":True, "nonzero":True, "positive":False,
-                           "prime":False, "composite":False, "real":True,
-                           "zero":False}
-                if asm == asm_default:
-                    xtra = ""
-                elif asm == asm_real:
-                    xtra = ", real=True"
-                elif asm == asm_pos:
-                    xtra = ", positive=True"
-                elif asm == asm_neg:
-                    xtra = ", negative=True"
-                else:
-                    xtra = ""
-                    for (key, val) in asm.items():
-                        xtra = xtra + ", %s=%s" % (key, val)
-                return "%s(%s%s)" % (expr.__class__.__name__,
-                                     self._print(expr.name), xtra)
-        #
-        def my_srepr(expr, **settings):
-            """return expr in repr form w/ assumptions listed"""
-            return _ReprPrinter_w_asm(settings).doprint(expr)
-    except:
-        echo_exception_stdout("in python_header defining fcns block 2")
-        raise
-
-
 try:
     def objectfilter(x):
         """Perform final fixes before passing objects back to Octave"""
@@ -195,6 +129,7 @@ try:
         OCTCODE_DOUBLE = 1002
         OCTCODE_STR = 1003
         OCTCODE_BOOL = 1005
+        OCTCODE_COMPLEX = 1006
         OCTCODE_DICT = 1010
         OCTCODE_SYM = 1020
         x = objectfilter(x)
@@ -210,7 +145,9 @@ try:
                 _d = x.shape
             elif isinstance(x, sp.MatrixExpr):
                 # nan for symbolic size
-                _d = [float('nan') if (isinstance(r, sp.Basic) and not r.is_Integer) else r for r in x.shape]
+                _d = [float(r) if (isinstance(r, sp.Basic) and r.is_Integer)
+                      else float('nan') if isinstance(r, sp.Basic)
+                      else r for r in x.shape]
             elif x is None:
                 _d = (1,1)
             else:
@@ -225,7 +162,7 @@ try:
             f = ET.SubElement(a, "f")
             f.text = str(OCTCODE_SYM)
             f = ET.SubElement(a, "f")
-            f.text = my_srepr(x)
+            f.text = sympy.srepr(x)
             f = ET.SubElement(a, "f")
             f.text = str(_d[0])
             f = ET.SubElement(a, "f")
@@ -240,7 +177,7 @@ try:
             c = ET.SubElement(et, "list")
             for y in x:
                 octoutput(y, c)
-        elif isinstance(x, int):
+        elif isinstance(x, sp.compatibility.integer_types):
             a = ET.SubElement(et, "item")
             f = ET.SubElement(a, "f")
             f.text = str(OCTCODE_INT)
@@ -253,7 +190,15 @@ try:
             f.text = str(OCTCODE_DOUBLE)
             f = ET.SubElement(a, "f")
             f.text = d2hex(x)
-        elif isinstance(x, str) or (sys.version_info < (3, 0) and isinstance(x, unicode)):
+        elif isinstance(x, complex):
+            a = ET.SubElement(et, "item")
+            f = ET.SubElement(a, "f")
+            f.text = str(OCTCODE_COMPLEX)
+            f = ET.SubElement(a, "f")
+            f.text = d2hex(x.real)
+            f = ET.SubElement(a, "f")
+            f.text = d2hex(x.imag)
+        elif isinstance(x, sp.compatibility.string_types):
             a = ET.SubElement(et, "item")
             f = ET.SubElement(a, "f")
             f.text = str(OCTCODE_STR)
